@@ -4,6 +4,9 @@ use crate::db_connectors::{dynamodb as dynamodb_connector, is_dynamodb};
 use crate::db_connectors::{is_mongodb, mongodb as mongodb_connector};
 #[cfg(feature = "postgresql")]
 use crate::db_connectors::{is_postgresql, postgresql_connector};
+#[cfg(feature = "sqlite")]
+use crate::db_connectors::{is_sqlite, sqlite_connector};
+
 use crate::error_messages::ERROR_DB_SETUP;
 use crate::{BotVersion, CsmlBot, Database, EngineError};
 use csml_interpreter::data::csml_logs::*;
@@ -18,18 +21,21 @@ pub fn create_bot_version(
             None,
             None,
             None,
-            format!("db call create bot version, bot_id: {:?}", bot_id)
+            format!("db call create bot version, bot_id: {:?}", bot_id),
         ),
-        LogLvl::Info
+        LogLvl::Info,
     );
     csml_logger(
         CsmlLog::new(
             None,
             None,
             None,
-            format!("db call create bot version, bot_id: {:?}, csml_bot: {:?}", bot_id, csml_bot)
+            format!(
+                "db call create bot version, bot_id: {:?}, csml_bot: {:?}",
+                bot_id, csml_bot
+            ),
         ),
-        LogLvl::Debug
+        LogLvl::Debug,
     );
 
     #[cfg(feature = "mongo")]
@@ -47,12 +53,22 @@ pub fn create_bot_version(
         let dynamo_bot = crate::data::to_dynamo_bot(&csml_bot);
 
         let flows = serde_json::json!(&csml_bot.flows);
+        let flow_modules = match csml_bot.modules {
+            Some(ref modules) => serde_json::json!(&modules),
+            None => {
+                let modules: Vec<csml_interpreter::data::csml_bot::Module> = vec![];
+
+                serde_json::json!(modules)
+            }
+        };
+
         let bot = serde_json::json!(dynamo_bot).to_string();
 
         let version_id = dynamodb_connector::bot::create_bot_version(
             bot_id.clone(),
             bot,
             flows.to_string(),
+            flow_modules.to_string(),
             db,
         )?;
 
@@ -66,11 +82,19 @@ pub fn create_bot_version(
         let serializable_bot = crate::data::to_serializable_bot(&csml_bot);
         let bot = serde_json::json!(serializable_bot).to_string();
 
-        let version_id = postgresql_connector::bot::create_bot_version(
-            bot_id.clone(),
-            bot,
-            db,
-        )?;
+        let version_id = postgresql_connector::bot::create_bot_version(bot_id.clone(), bot, db)?;
+
+        return Ok(version_id);
+    }
+
+    #[cfg(feature = "sqlite")]
+    if is_sqlite() {
+        let db = sqlite_connector::get_db(db)?;
+
+        let serializable_bot = crate::data::to_serializable_bot(&csml_bot);
+        let bot = serde_json::json!(serializable_bot).to_string();
+
+        let version_id = sqlite_connector::bot::create_bot_version(bot_id.clone(), bot, db)?;
 
         return Ok(version_id);
     }
@@ -87,9 +111,9 @@ pub fn get_last_bot_version(
             None,
             None,
             None,
-            format!("db call get last bot version, bot_id: {:?}", bot_id)
+            format!("db call get last bot version, bot_id: {:?}", bot_id),
         ),
-        LogLvl::Info
+        LogLvl::Info,
     );
 
     #[cfg(feature = "mongo")]
@@ -110,6 +134,12 @@ pub fn get_last_bot_version(
         return postgresql_connector::bot::get_last_bot_version(&bot_id, db);
     }
 
+    #[cfg(feature = "sqlite")]
+    if is_sqlite() {
+        let db = sqlite_connector::get_db(db)?;
+        return sqlite_connector::bot::get_last_bot_version(&bot_id, db);
+    }
+
     Err(EngineError::Manager(ERROR_DB_SETUP.to_owned()))
 }
 
@@ -123,18 +153,21 @@ pub fn get_by_version_id(
             None,
             None,
             None,
-            format!("db call get by version id, version_id: {:?}", version_id)
+            format!("db call get by version id, version_id: {:?}", version_id),
         ),
-        LogLvl::Info
+        LogLvl::Info,
     );
     csml_logger(
         CsmlLog::new(
             None,
             None,
             None,
-            format!("db call get by version id, version_id: {:?}, bot_id: {:?}", version_id, _bot_id)
+            format!(
+                "db call get by version id, version_id: {:?}, bot_id: {:?}",
+                version_id, _bot_id
+            ),
         ),
-        LogLvl::Debug
+        LogLvl::Debug,
     );
 
     #[cfg(feature = "mongo")]
@@ -155,6 +188,12 @@ pub fn get_by_version_id(
         return postgresql_connector::bot::get_bot_by_version_id(&version_id, db);
     }
 
+    #[cfg(feature = "sqlite")]
+    if is_sqlite() {
+        let db = sqlite_connector::get_db(db)?;
+        return sqlite_connector::bot::get_bot_by_version_id(&version_id, db);
+    }
+
     Err(EngineError::Manager(ERROR_DB_SETUP.to_owned()))
 }
 
@@ -169,18 +208,21 @@ pub fn get_bot_versions(
             None,
             None,
             None,
-            format!("db call get bot versions, bot_id: {:?}", bot_id)
+            format!("db call get bot versions, bot_id: {:?}", bot_id),
         ),
-        LogLvl::Info
+        LogLvl::Info,
     );
     csml_logger(
         CsmlLog::new(
             None,
             None,
             None,
-            format!("db call get bot versions, bot_id: {:?}, limit {:?}, pagination_key {:?}", bot_id, limit, pagination_key)
+            format!(
+                "db call get bot versions, bot_id: {:?}, limit {:?}, pagination_key {:?}",
+                bot_id, limit, pagination_key
+            ),
         ),
-        LogLvl::Debug
+        LogLvl::Debug,
     );
 
     #[cfg(feature = "mongo")]
@@ -205,6 +247,12 @@ pub fn get_bot_versions(
         return postgresql_connector::bot::get_bot_versions(&bot_id, limit, pagination_key, db);
     }
 
+    #[cfg(feature = "sqlite")]
+    if is_sqlite() {
+        let db = sqlite_connector::get_db(db)?;
+        return sqlite_connector::bot::get_bot_versions(&bot_id, limit, pagination_key, db);
+    }
+
     Err(EngineError::Manager(ERROR_DB_SETUP.to_owned()))
 }
 
@@ -218,18 +266,18 @@ pub fn delete_bot_version(
             None,
             None,
             None,
-            format!("db call delete bot version, version_id: {:?}", version_id)
+            format!("db call delete bot version, version_id: {:?}", version_id),
         ),
-        LogLvl::Info
+        LogLvl::Info,
     );
     csml_logger(
         CsmlLog::new(
             None,
             None,
             None,
-            format!("db call delete bot version, version_id: {:?}", version_id)
+            format!("db call delete bot version, version_id: {:?}", version_id),
         ),
-        LogLvl::Debug
+        LogLvl::Debug,
     );
 
     #[cfg(feature = "mongo")]
@@ -250,27 +298,28 @@ pub fn delete_bot_version(
         return postgresql_connector::bot::delete_bot_version(version_id, db);
     }
 
+    #[cfg(feature = "sqlite")]
+    if is_sqlite() {
+        let db = sqlite_connector::get_db(db)?;
+        return sqlite_connector::bot::delete_bot_version(version_id, db);
+    }
+
     Err(EngineError::Manager(ERROR_DB_SETUP.to_owned()))
 }
 
 pub fn delete_bot_versions(bot_id: &str, db: &mut Database) -> Result<(), EngineError> {
     csml_logger(
-        CsmlLog::new(
-            None,
-            None,
-            None,
-            format!("db call delete bot versions")
-        ),
-        LogLvl::Info
+        CsmlLog::new(None, None, None, format!("db call delete bot versions")),
+        LogLvl::Info,
     );
     csml_logger(
         CsmlLog::new(
             None,
             None,
             None,
-            format!("db call delete bot versions, bot_id: {:?}", bot_id)
+            format!("db call delete bot versions, bot_id: {:?}", bot_id),
         ),
-        LogLvl::Debug
+        LogLvl::Debug,
     );
 
     #[cfg(feature = "mongo")]
@@ -291,28 +340,28 @@ pub fn delete_bot_versions(bot_id: &str, db: &mut Database) -> Result<(), Engine
         return postgresql_connector::bot::delete_bot_versions(bot_id, db);
     }
 
+    #[cfg(feature = "sqlite")]
+    if is_sqlite() {
+        let db = sqlite_connector::get_db(db)?;
+        return sqlite_connector::bot::delete_bot_versions(bot_id, db);
+    }
+
     Err(EngineError::Manager(ERROR_DB_SETUP.to_owned()))
 }
 
-
 pub fn delete_all_bot_data(bot_id: &str, db: &mut Database) -> Result<(), EngineError> {
     csml_logger(
-        CsmlLog::new(
-            None,
-            None,
-            None,
-            format!("db call delete all bot data")
-        ),
-        LogLvl::Info
+        CsmlLog::new(None, None, None, format!("db call delete all bot data")),
+        LogLvl::Info,
     );
     csml_logger(
         CsmlLog::new(
             None,
             None,
             None,
-            format!("db call delete all bot data, bot_id: {:?}", bot_id)
+            format!("db call delete all bot data, bot_id: {:?}", bot_id),
         ),
-        LogLvl::Debug
+        LogLvl::Debug,
     );
 
     #[cfg(feature = "mongo")]
@@ -331,7 +380,6 @@ pub fn delete_all_bot_data(bot_id: &str, db: &mut Database) -> Result<(), Engine
         return Ok(());
     }
 
-    
     #[cfg(feature = "dynamo")]
     if is_dynamodb() {
         delete_bot_versions(bot_id, db)?;
@@ -358,5 +406,17 @@ pub fn delete_all_bot_data(bot_id: &str, db: &mut Database) -> Result<(), Engine
         return Ok(());
     }
 
+    #[cfg(feature = "sqlite")]
+    if is_sqlite() {
+        delete_bot_versions(bot_id, db)?;
+
+        let db = sqlite_connector::get_db(db)?;
+
+        sqlite_connector::conversations::delete_all_bot_data(bot_id, db)?;
+        sqlite_connector::memories::delete_all_bot_data(bot_id, db)?;
+        sqlite_connector::state::delete_all_bot_data(bot_id, db)?;
+        return Ok(());
+    }
+
     Err(EngineError::Manager(ERROR_DB_SETUP.to_owned()))
 }
