@@ -1,18 +1,19 @@
-use crate::data::{DynamoDbClient, DynamoBot, DynamoBotBincode, };
+use crate::data::{DynamoBot, DynamoBotBincode, DynamoDbClient};
+use crate::db_connectors::dynamodb::utils::*;
 use crate::db_connectors::{
-    dynamodb::{nodes::delete_conversation_nodes ,aws_s3, Bot, Conversation, DynamoDbKey, Class},
+    dynamodb::{aws_s3, Bot, Class, DynamoDbKey},
     BotVersion,
 };
-use csml_interpreter::data::{csml_flow::CsmlFlow};
+use crate::EngineError;
+use csml_interpreter::data::{csml_bot::Module, csml_flow::CsmlFlow};
 use rusoto_dynamodb::*;
 use std::collections::HashMap;
-use crate::EngineError;
-use crate::db_connectors::dynamodb::utils::*;
 
 pub fn create_bot_version(
     bot_id: String,
     bot: String,
     flows: String,
+    flow_modules: String,
     db: &mut DynamoDbClient,
 ) -> Result<String, EngineError> {
     let data: Bot = Bot::new(bot_id, bot);
@@ -30,6 +31,12 @@ pub fn create_bot_version(
     let key = format!("bots/{}/versions/{}/flows.json", &data.id, &data.version_id);
     aws_s3::put_object(db, &key, flows)?;
 
+    let key = format!(
+        "bots/{}/versions/{}/modules.json",
+        &data.id, &data.version_id
+    );
+    aws_s3::put_object(db, &key, flow_modules)?;
+
     Ok(data.version_id.to_owned())
 }
 
@@ -40,6 +47,13 @@ pub fn get_flows(key: &str, db: &mut DynamoDbClient) -> Result<Vec<CsmlFlow>, En
     Ok(flows)
 }
 
+pub fn get_modules(key: &str, db: &mut DynamoDbClient) -> Result<Vec<Module>, EngineError> {
+    let object = aws_s3::get_object(db, key)?;
+    let modules: Vec<Module> = serde_json::from_str(&object).unwrap();
+
+    Ok(modules)
+}
+
 fn query_bot_version(
     bot_id: &str,
     limit: i64,
@@ -90,7 +104,10 @@ fn query_bot_version(
     };
 
     let query = db.client.query(input);
-    let data = db.runtime.block_on(query)?;
+    let data = match db.runtime.block_on(query) {
+        Ok(data) => data,
+        Err(e) => return Err(EngineError::Manager(format!("query_bot_version {:?}", e))),
+    };
 
     Ok(data)
 }
@@ -123,13 +140,13 @@ pub fn get_bot_versions(
         let data: Bot = serde_dynamodb::from_hashmap(item.to_owned())?;
 
         let csml_bot: DynamoBot = match base64::decode(&data.bot) {
-            Ok(base64decoded) =>  {
+            Ok(base64decoded) => {
                 match bincode::deserialize::<DynamoBotBincode>(&base64decoded[..]) {
                     Ok(bot) => bot.to_bot(),
-                    Err(_) => serde_json::from_str(&data.bot).unwrap()
+                    Err(_) => serde_json::from_str(&data.bot).unwrap(),
                 }
-            },
-            Err(_) => serde_json::from_str(&data.bot).unwrap()
+            }
+            Err(_) => serde_json::from_str(&data.bot).unwrap(),
         };
 
         let mut json = serde_json::json!({
@@ -185,17 +202,20 @@ pub fn get_bot_by_version_id(
                 Ok(base64decoded) => {
                     match bincode::deserialize::<DynamoBotBincode>(&base64decoded[..]) {
                         Ok(bot) => bot.to_bot(),
-                        Err(_) => serde_json::from_str(&bot.bot).unwrap()
+                        Err(_) => serde_json::from_str(&bot.bot).unwrap(),
                     }
-                },
-                Err(_) => serde_json::from_str(&bot.bot).unwrap()
+                }
+                Err(_) => serde_json::from_str(&bot.bot).unwrap(),
             };
 
             let key = format!("bots/{}/versions/{}/flows.json", bot_id, version_id);
             let flows = get_flows(&key, db)?;
 
+            let key = format!("bots/{}/versions/{}/modules.json", bot_id, version_id);
+            let modules = get_modules(&key, db)?;
+
             Ok(Some(BotVersion {
-                bot: csml_bot.to_bot(flows),
+                bot: csml_bot.to_bot(flows, modules),
                 version_id: bot.version_id,
                 engine_version: env!("CARGO_PKG_VERSION").to_owned(),
             }))
@@ -252,7 +272,15 @@ pub fn get_last_bot_version(
     };
 
     let query = db.client.query(input);
-    let data = db.runtime.block_on(query)?;
+    let data = match db.runtime.block_on(query) {
+        Ok(data) => data,
+        Err(e) => {
+            return Err(EngineError::Manager(format!(
+                "get_last_bot_version {:?}",
+                e
+            )))
+        }
+    };
 
     // The query returns an array of items (max 1, based on the limit param above).
     // If 0 item is returned it means that there is no open conversation, so simply return None
@@ -264,20 +292,21 @@ pub fn get_last_bot_version(
 
     let bot: Bot = serde_dynamodb::from_hashmap(item)?;
     let csml_bot: DynamoBot = match base64::decode(&bot.bot) {
-        Ok(base64decoded) =>  {
-            match bincode::deserialize::<DynamoBotBincode>(&base64decoded[..]) {
-                Ok(bot) => bot.to_bot(),
-                Err(_) => serde_json::from_str(&bot.bot).unwrap()
-            }
+        Ok(base64decoded) => match bincode::deserialize::<DynamoBotBincode>(&base64decoded[..]) {
+            Ok(bot) => bot.to_bot(),
+            Err(_) => serde_json::from_str(&bot.bot).unwrap(),
         },
-        Err(_) => serde_json::from_str(&bot.bot).unwrap()
+        Err(_) => serde_json::from_str(&bot.bot).unwrap(),
     };
 
     let key = format!("bots/{}/versions/{}/flows.json", bot_id, bot.version_id);
     let flows = get_flows(&key, db)?;
 
+    let key = format!("bots/{}/versions/{}/modules.json", bot_id, bot.version_id);
+    let modules = get_modules(&key, db)?;
+
     Ok(Some(BotVersion {
-        bot: csml_bot.to_bot(flows),
+        bot: csml_bot.to_bot(flows, modules),
         version_id: bot.version_id,
         engine_version: env!("CARGO_PKG_VERSION").to_owned(),
     }))
@@ -291,6 +320,9 @@ pub fn delete_bot_version(
     let key = format!("bots/{}/versions/{}/flows.json", bot_id, version_id);
     aws_s3::delete_object(db, &key)?;
 
+    let key = format!("bots/{}/versions/{}/modules.json", bot_id, version_id);
+    aws_s3::delete_object(db, &key)?;
+
     let item_key = DynamoDbKey {
         hash: Bot::get_hash(bot_id),
         range: Bot::get_range(version_id),
@@ -308,10 +340,7 @@ pub fn delete_bot_version(
     Ok(())
 }
 
-pub fn delete_bot_versions(
-    bot_id: &str,
-    db: &mut DynamoDbClient,
-) -> Result<(), EngineError> {
+pub fn delete_bot_versions(bot_id: &str, db: &mut DynamoDbClient) -> Result<(), EngineError> {
     let mut pagination_key = None;
 
     loop {
@@ -334,6 +363,9 @@ pub fn delete_bot_versions(
             let key = format!("bots/{}/versions/{}/flows.json", bot_id, data.version_id);
             aws_s3::delete_object(db, &key)?;
 
+            let key = format!("bots/{}/versions/{}/modules.json", bot_id, data.version_id);
+            aws_s3::delete_object(db, &key)?;
+
             let key = serde_dynamodb::to_hashmap(&DynamoDbKey {
                 hash: Bot::get_hash(bot_id),
                 range: Bot::get_range(&data.version_id),
@@ -346,9 +378,9 @@ pub fn delete_bot_versions(
         }
 
         let request_items = [(get_table_name()?, write_requests)]
-        .iter()
-        .cloned()
-        .collect();
+            .iter()
+            .cloned()
+            .collect();
 
         let input = BatchWriteItemInput {
             request_items,
@@ -359,7 +391,7 @@ pub fn delete_bot_versions(
 
         pagination_key = data.last_evaluated_key;
         if let None = &pagination_key {
-            return Ok(())
+            return Ok(());
         }
     }
 }
@@ -417,7 +449,10 @@ fn query_bot_info(
     };
 
     let future = db.client.query(input);
-    let data = db.runtime.block_on(future)?;
+    let data = match db.runtime.block_on(future) {
+        Ok(data) => data,
+        Err(e) => return Err(EngineError::Manager(format!("query_bot_info {:?}", e))),
+    };
 
     Ok(data)
 }
@@ -431,7 +466,7 @@ pub fn delete_all_bot_data(
 
     loop {
         // 25 is the Maximum operations in a single request for BatchWriteItemInput
-        let data = query_bot_info(bot_id, class, 25, db, pagination_key, )?;
+        let data = query_bot_info(bot_id, class, 25, db, pagination_key)?;
 
         // The query returns an array of items (max 10, based on the limit param above).
         // If 0 item is returned it means that there is no open conversation, so simply return None
@@ -446,13 +481,6 @@ pub fn delete_all_bot_data(
         for item in items {
             let class: Class = serde_dynamodb::from_hashmap(item.to_owned())?;
 
-            // only for class 'conversation' we need to get the conversation id in order to delete the path class 
-            // witch 'hash' is base in the conversation id
-            if class.class == "conversation" {
-                let conversation_id = Conversation::get_conversation_id_from_range(&class.range);
-                delete_conversation_nodes(&conversation_id, db)?;
-            }
-
             let key = serde_dynamodb::to_hashmap(&DynamoDbKey {
                 hash: class.hash,
                 range: class.range,
@@ -465,9 +493,9 @@ pub fn delete_all_bot_data(
         }
 
         let request_items = [(get_table_name()?, write_requests)]
-        .iter()
-        .cloned()
-        .collect();
+            .iter()
+            .cloned()
+            .collect();
 
         let input = BatchWriteItemInput {
             request_items,
@@ -478,7 +506,7 @@ pub fn delete_all_bot_data(
 
         pagination_key = data.last_evaluated_key;
         if let None = &pagination_key {
-            return Ok(())
+            return Ok(());
         }
     }
 }
