@@ -4,11 +4,13 @@ use crate::db_connectors::{dynamodb as dynamodb_connector, is_dynamodb};
 use crate::db_connectors::{is_mongodb, mongodb as mongodb_connector};
 #[cfg(feature = "postgresql")]
 use crate::db_connectors::{is_postgresql, postgresql_connector};
+#[cfg(feature = "sqlite")]
+use crate::db_connectors::{is_sqlite, sqlite_connector};
 
-use csml_interpreter::data::csml_logs::{LogLvl, CsmlLog, csml_logger};
-use crate::error_messages::ERROR_DB_SETUP;
-use crate::{Database, ConversationInfo, EngineError, Client};
 use crate::db_connectors::utils::*;
+use crate::error_messages::ERROR_DB_SETUP;
+use crate::{Client, ConversationInfo, Database, EngineError};
+use csml_interpreter::data::csml_logs::{csml_logger, CsmlLog, LogLvl};
 
 pub fn add_messages_bulk(
     data: &mut ConversationInfo,
@@ -21,18 +23,18 @@ pub fn add_messages_bulk(
             None,
             None,
             None,
-            format!("db call save messages {:?}", msgs)
+            format!("db call save messages {:?}", msgs),
         ),
-        LogLvl::Info
+        LogLvl::Info,
     );
     csml_logger(
         CsmlLog::new(
             Some(&data.client),
             None,
             None,
-            format!("db call save messages {:?}", msgs)
+            format!("db call save messages {:?}", msgs),
         ),
-        LogLvl::Debug
+        LogLvl::Debug,
     );
 
     #[cfg(feature = "mongo")]
@@ -44,7 +46,7 @@ pub fn add_messages_bulk(
             &msgs,
             interaction_order,
             direction,
-            expires_at
+            expires_at,
         );
     }
 
@@ -74,6 +76,19 @@ pub fn add_messages_bulk(
         );
     }
 
+    #[cfg(feature = "sqlite")]
+    if is_sqlite() {
+        let expires_at = get_expires_at_for_sqlite(data.ttl);
+
+        return sqlite_connector::messages::add_messages_bulk(
+            data,
+            &msgs,
+            interaction_order,
+            direction,
+            expires_at,
+        );
+    }
+
     Err(EngineError::Manager(ERROR_DB_SETUP.to_owned()))
 }
 
@@ -82,24 +97,16 @@ pub fn get_client_messages(
     db: &mut Database,
     limit: Option<i64>,
     pagination_key: Option<String>,
+    from_date: Option<i64>,
+    to_date: Option<i64>,
 ) -> Result<serde_json::Value, EngineError> {
     csml_logger(
-        CsmlLog::new(
-            None,
-            None,
-            None,
-            format!("db call get messages")
-        ),
-        LogLvl::Info
+        CsmlLog::new(None, None, None, format!("db call get messages")),
+        LogLvl::Info,
     );
     csml_logger(
-        CsmlLog::new(
-            Some(client),
-            None,
-            None,
-            format!("db call get messages")
-        ),
-        LogLvl::Debug
+        CsmlLog::new(Some(client), None, None, format!("db call get messages")),
+        LogLvl::Debug,
     );
 
     #[cfg(feature = "mongo")]
@@ -112,6 +119,8 @@ pub fn get_client_messages(
             db,
             limit,
             pagination_key,
+            from_date,
+            to_date,
         );
     }
 
@@ -120,12 +129,25 @@ pub fn get_client_messages(
         let db = dynamodb_connector::get_db(db)?;
         let pagination_key = dynamodb_connector::get_pagination_key(pagination_key)?;
 
-        return dynamodb_connector::messages::get_client_messages(
-            client,
-            db,
-            limit,
-            pagination_key,
-        );
+        match from_date {
+            Some(from_date) => {
+                return dynamodb_connector::messages::get_client_messages_from_date(
+                    db,
+                    limit,
+                    pagination_key,
+                    from_date,
+                    to_date,
+                );
+            }
+            None => {
+                return dynamodb_connector::messages::get_client_messages(
+                    client,
+                    db,
+                    limit,
+                    pagination_key,
+                )
+            }
+        }
     }
 
     #[cfg(feature = "postgresql")]
@@ -137,6 +159,22 @@ pub fn get_client_messages(
             db,
             limit,
             pagination_key,
+            from_date,
+            to_date,
+        );
+    }
+
+    #[cfg(feature = "sqlite")]
+    if is_sqlite() {
+        let db = sqlite_connector::get_db(db)?;
+
+        return sqlite_connector::messages::get_client_messages(
+            client,
+            db,
+            limit,
+            pagination_key,
+            from_date,
+            to_date,
         );
     }
 
