@@ -2,7 +2,7 @@ use csml_engine::{
     data::{BotOpt, CsmlRequest},
     start_conversation,
 };
-use csml_interpreter::data::{csml_bot::CsmlBot, csml_flow::CsmlFlow, Client};
+use csml_interpreter::data::{csml_bot::{CsmlBot}, csml_flow::CsmlFlow, Client};
 use serde::{Deserialize, Serialize};
 use serde_json::json;
 use std::fs;
@@ -76,18 +76,18 @@ fn init_bot(bot_name: &str) -> Result<CsmlBot, std::io::Error> {
     let bot = CsmlBot {
         id: bot_info.name.clone(),
         name: bot_info.name.clone(),
-        fn_endpoint: None,
+        apps_endpoint: None,
         flows: bot_flows,
         native_components: None,
         custom_components: None,
         default_flow: bot_info.default_flow.clone(),
         bot_ast: None,
-        env: Some(
-            serde_json::json!({
-                "random": "value",
-                "toto": "key",
-            })
-        )
+        no_interruption_delay: None,
+        env: Some(serde_json::json!({
+            "random": "value",
+            "toto": "key",
+        })),
+        modules: None,
     };
 
     Ok(bot)
@@ -107,6 +107,8 @@ fn init_request(string: &str, bot_id: String, channel_id: String) -> CsmlRequest
             "content": { "text": string},
         }),
         metadata: json!({"some": "custom-value"}),
+        ttl_duration: None,
+        low_data_mode: None
     }
 }
 
@@ -281,7 +283,7 @@ fn ok_test_goto_var() {
 
     let events = &["/flow5"];
 
-    let messages = &["flow5 start","flow5 step1", "flow4"];
+    let messages = &["flow5 start", "flow5 step1", "flow4"];
 
     let channel_id = Uuid::new_v4().to_string();
     let bot_id = match std::env::var("GITHUB_SHA") {
@@ -332,7 +334,17 @@ fn ok_test_memory() {
     let bot = init_bot("goto_flow").unwrap();
 
     let events = &["/flow6"];
-    let messages = &["flow6 start","{\"val\":1}", "message", "4", "4.2", "[21,42,84]" ];
+    let messages = &[
+        "flow6 start",
+        "< random > is used before it was saved in memory at line 8, column 30 at flow [flow6]",
+        "{\"val\":1}",
+        "message",
+        "4",
+        "4.2",
+        "[21,42,84]",
+        "< random > is used before it was saved in memory at line 17, column 9 at flow [flow6]",
+        "Null",
+    ];
 
     let channel_id = Uuid::new_v4().to_string();
     let bot_id = match std::env::var("GITHUB_SHA") {
@@ -354,10 +366,12 @@ fn ok_test_memory() {
             Ok(obj) => {
                 let messages = obj["messages"].as_array().unwrap();
                 for message in messages.iter() {
+                    let content_type = message["payload"]["content_type"].as_str().unwrap();
+
                     output_message.push(
-                        message["payload"]["content"]["text"]
+                        message["payload"]["content"][content_type]
                             .as_str()
-                            .unwrap()
+                            .unwrap_or("Null")
                             .to_owned(),
                     );
                 }
